aset
(aset array index ... value)
Stores value at the subscripts, mutating the array, and answers value. One index per dimension is required.
(aset array index ... value)
Stores value at the subscripts, mutating the array, and answers value. One index per dimension is required.