char
(char x)
The character itself, or the code-char of the truncated code point of a number;
anything else signals, like the oracle. int reads it back. As a value a
one-argument lambda.
(char x)
The character itself, or the code-char of the truncated code point of a number;
anything else signals, like the oracle. int reads it back. As a value a
one-argument lambda.