completing
(completing f) / (completing f cf)
Answers a reducing function with f's init and step arities and cf as the completion
(identity without one), so a two-argument f can finish a transduce. As a value one
or two arguments.
(completing f) / (completing f cf)
Answers a reducing function with f's init and step arities and cf as the completion
(identity without one), so a two-argument f can finish a transduce. As a value one
or two arguments.