drop-while
(drop-while pred coll) / (drop-while pred)
Answers coll's seq view past the truthy prefix, sharing the tail. As a value
a two-argument lambda.
(drop-while pred) is its transducer, as a value too.
(drop-while pred coll) / (drop-while pred)
Answers coll's seq view past the truthy prefix, sharing the tail. As a value
a two-argument lambda.
(drop-while pred) is its transducer, as a value too.