(rontolisp) docs
← Transducers

eduction

(eduction xform* coll)

Answers coll stepped through the transducers, composed like comp. As a value transducers then one collection.

Deviation: the eduction is that seq, computed once -- strictly over a strict input, lazily over a lazy one -- where the oracle re-runs the transformation every time it is reduced; println prints it as the seq, where the oracle prints the object (prn agrees).