clojure.string/ends-with?
(clojure.string/ends-with? s sub)
Answers whether s ends with the literal string sub. Works as a function value too.
(clojure.string/ends-with? s sub)
Answers whether s ends with the literal string sub. Works as a function value too.