(rontolisp) docs
← Namespaces

find-ns

(find-ns sym)

clojure.core/find-ns: the namespace the symbol names, or nil when the program created none of that name above the call (with ns or in-ns), required none and clj -M loads none first (clojure.core, clojure.edn, clojure.java.io, clojure.string). As a value a one-argument function.

demo nil