fn?
(fn? x)
Answers whether x is a function, T-or-false. A keyword, a set or a map is no
function here even where it can be called.
true true false false
(fn? x)
Answers whether x is a function, T-or-false. A keyword, a set or a map is no
function here even where it can be called.
true true false false