(rontolisp) docs
← Syntax and definition

if

(if test then else?)

Evaluates test and answers then when it is truthy, else else (or nil without one). nil and false are both falsey and everything else is truthy -- the test is an explicit null-or-false check, bound once to a temporary.