if-not
(if-not test then) / (if-not test then else)
Answers then unless the test is truthy, else the else branch (nil without
one).
(if-not test then) / (if-not test then else)
Answers then unless the test is truthy, else the else branch (nil without
one).