clojure.string/includes?
(clojure.string/includes? s sub)
Answers whether the literal string sub occurs anywhere in s. Works as a function value too.
(clojure.string/includes? s sub)
Answers whether the literal string sub occurs anywhere in s. Works as a function value too.