infinite?
(infinite? x)
clojure.core/infinite?: true for ##Inf and ##-Inf; any other number is false, and anything that is no number signals, like the oracle. As a value a one-argument function.
(infinite? x)
clojure.core/infinite?: true for ##Inf and ##-Inf; any other number is false, and anything that is no number signals, like the oracle. As a value a one-argument function.