int
(int x)
Answers the truncation toward zero, like quot of one. A non-number signals,
like the oracle. As a value a one-argument lambda.
(int x)
Answers the truncation toward zero, like quot of one. A non-number signals,
like the oracle. As a value a one-argument lambda.