iterate
(iterate f x)
Answers x, (f x), (f (f x)), ... as a lazy seq, applying through the same call
path as map (real functions and collection values alike). Only terminates behind
take.
(iterate f x)
Answers x, (f x), (f (f x)), ... as a lazy seq, applying through the same call
path as map (real functions and collection values alike). Only terminates behind
take.