(rontolisp) docs
← Higher-order functions

juxt

(juxt f g...)

Answers a function returning the vector of every given function applied to its arguments. Keywords and collections work as functions, like everywhere else. As a value it takes one or more functions.