(rontolisp) docs
← Seqs

lazy-cat

(lazy-cat expr...)

Answers the lazy concatenation of the expressions, each behind its own lazy-seq: equivalent to (concat (lazy-seq expr) ...) but every member stays lazy, so an infinite member terminates behind take. (lazy-cat) is nil.