(rontolisp) docs
← Seqs

list*

(list* x... coll) / (list* coll)

Answers a list of the leading arguments followed by the seq view of the last; with one argument, just its seq (signalling for a non-collection). A right fold of cons over the seq view.