(rontolisp) docs
← Seqs

map-indexed

(map-indexed f coll) / (map-indexed f)

Answers f of the index and the item over coll's seq view. Indexing starts at 0. A lazy input answers a lazy seq, a strict one a strict list. As a value a two-argument lambda.

(map-indexed f) is its transducer, as a value too.