(rontolisp) docs
← Seqs

mapcat

(mapcat f coll...) / (mapcat f)

Maps f over the collections and concats the mapped seq views, strictly (nil-safe: a nil result contributes nothing, like concat). (mapcat f) is its transducer, (comp (map f) cat). As a value a rest lambda, which answers the transducer of the function alone.