(rontolisp) docs
← Higher-order functions

partial

(partial f args...)

Answers f over the fixed arguments plus whatever arrives. The fixed arguments run once. As a value the function, then the fixed arguments.