(rontolisp) docs
← Multimethods and hierarchies

prefer-method

(prefer-method multifn val1 val2)

Records that val1 wins over val2 when the dispatch search finds both as candidate ancestors and neither is strictly more specific. Answers the multimethod. Without it, such a tie signals Multiple methods ....