ratio?
(ratio? x)
clojure.core/ratio?: true for a ratio, a rational that is no integer. 1.5M reads as 3/2 here, so it answers true (the oracle: false). As a value a one-argument function.
(ratio? x)
clojure.core/ratio?: true for a ratio, a rational that is no integer. 1.5M reads as 3/2 here, so it answers true (the oracle: false). As a value a one-argument function.