realized?
(realized? x)
clojure.core/realized?: Whether the lazy seq x has run its body. A list (what a verb answers over a strict input) is realized, true where the oracle's unrealized lazy seq is false; an iterate, cycle or repeat seq is realized only once forced (the oracle: from the start). Anything else signals, like the oracle. As a value a one-argument function.