(rontolisp) docs
← Seqs

remove

(remove pred coll) / (remove pred)

Answers the members of coll's seq view the predicate rejects, in order -- the complement of filter. A lazy input answers a lazy seq, a strict one a strict list. As a value a two-argument lambda.

(remove pred) is its transducer, as a value too.