(rontolisp) docs
← (clojure.set)

clojure.set/index

(clojure.set/index xrel ks)

Answers a map from each distinct narrowing of the members to the keys ks to the set of members narrowing to it. Reached also as alias/var or a referred bare index; works as a function value too.