clojure.set/select
(clojure.set/select pred xset)
Answers the members of xset for which pred is truthy; nil answers nil. Reached also as alias/var or a referred bare select; works as a function value too.
(clojure.set/select pred xset)
Answers the members of xset for which pred is truthy; nil answers nil. Reached also as alias/var or a referred bare select; works as a function value too.