split-at
(split-at n coll)
Answers [(take n coll) (drop n coll)]: the two halves of coll's seq at n.
An empty half is nil, where the oracle prints (). As a value a two-argument
function.
(split-at n coll)
Answers [(take n coll) (drop n coll)]: the two halves of coll's seq at n.
An empty half is nil, where the oracle prints (). As a value a two-argument
function.