subs
(subs s start)
(subs s start end)
Answers the substring of s from start to end (default the length). The core two-/three-
argument form, listed with the string library; as a value it is the two- or three-argument
lambda.
(subs s start)
(subs s start end)
Answers the substring of s from start to end (default the length). The core two-/three-
argument form, listed with the string library; as a value it is the two- or three-argument
lambda.