successful?
(successful? summary)
Answers true when the run-tests summary counts no failure and no error, false
otherwise.
Testing demo
Ran 1 tests containing 1 assertions.
0 failures, 0 errors.
true
(successful? summary)
Answers true when the run-tests summary counts no failure and no error, false
otherwise.
Testing demo
Ran 1 tests containing 1 assertions.
0 failures, 0 errors.
true