take-last
(take-last n coll)
Answers the last n members of coll's seq as a strict list, nil when n is not
positive or coll is empty. The whole input is realized, like the oracle's. As a
value a two-argument function.
(take-last n coll)
Answers the last n members of coll's seq as a strict list, nil when n is not
positive or coll is empty. The whole input is realized, like the oracle's. As a
value a two-argument function.