(rontolisp) docs
← Syntax and definition

when-first

(when-first [x coll] body...)

Binds the pattern to the head of the seq view and runs the body only when the collection is non-empty. The collection runs once.