when-not
(when-not test body...)
Runs the body unless the test is truthy, answering the last value -- nil
without a body or on a truthy test.
(when-not test body...)
Runs the body unless the test is truthy, answering the last value -- nil
without a body or on a truthy test.