zipmap
(zipmap keys vals)
Answers a fresh map pairing each key with its value, stopping at the shorter side, like the oracle. Later keys win. As a value a two-argument lambda.
(zipmap keys vals)
Answers a fresh map pairing each key with its value, stopping at the shorter side, like the oracle. Later keys win. As a value a two-argument lambda.