dissoc!
(dissoc! tr k & ks)
Removes each key from the transient map tr in place and answers tr; a key it does
not hold is ignored. Any other transient is refused. As a value a function of the same
arguments.
(dissoc! tr k & ks)
Removes each key from the transient map tr in place and answers tr; a key it does
not hold is ignored. Any other transient is refused. As a value a function of the same
arguments.