nthrest
(nthrest coll n)
Answers coll itself when n is not positive, else the rest past its first n
members -- nil once it runs out, where the oracle prints (). As a value a
two-argument function.
(nthrest coll n)
Answers coll itself when n is not positive, else the rest past its first n
members -- nil once it runs out, where the oracle prints (). As a value a
two-argument function.