pmap
(pmap f coll...)
Is map: there is no thread pool on any backend, so the calls run in order on the
calling thread and the printed answer is the oracle's. As a value the same function
as map.
(pmap f coll...)
Is map: there is no thread pool on any backend, so the calls run in order on the
calling thread and the printed answer is the oracle's. As a value the same function
as map.