update-vals
(update-vals m f)
Answers m with (f value) for every value: a map, record or Java Map answers a fresh
map, nil the empty map, and a vector stays a vector, like the oracle. As a value a
two-argument function.
(update-vals m f)
Answers m with (f value) for every value: a map, record or Java Map answers a fresh
map, nil the empty map, and a vector stays a vector, like the oracle. As a value a
two-argument function.