var-get
(var-get v)
clojure.core/var-get: the root of the var v, what deref of the var answers (a
binding in effect included). Unlike deref, a value that is no var signals, an atom
included. As a value a one-argument function.
(var-get v)
clojure.core/var-get: the root of the var v, what deref of the var answers (a
binding in effect included). Unlike deref, a value that is no var signals, an atom
included. As a value a one-argument function.