when
(when test body...)
Evaluates test and, when it is truthy, evaluates the body forms and answers the
last; otherwise answers nil without touching the body. nil and false are both
falsey, like every test here.
(when test body...)
Evaluates test and, when it is truthy, evaluates the body forms and answers the
last; otherwise answers nil without touching the body. nil and false are both
falsey, like every test here.