when-let
(when-let [p e] body...)
Binds the pattern to the init like let (destructuring included) and runs the
body only when the init is truthy. The init runs once.
(when-let [p e] body...)
Binds the pattern to the init like let (destructuring included) and runs the
body only when the init is truthy. The init runs once.